package com.flow.common.mybatis.handler;

import com.baomidou.mybatisplus.core.handlers.MetaObjectHandler;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import org.apache.ibatis.reflection.MetaObject;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import java.time.LocalDateTime;

/**
 * @author caixiaofeng
 * @version 1.0
 * @Description: <<字段填充>>
 * @company 无名人
 * @create 2021-02-22 10:03
 */
public class FieldMetaObjectHandler implements MetaObjectHandler {

    /**
     * 插入时填充
     *
     * @param metaObject
     */
    @Override
    public void insertFill(MetaObject metaObject) {
        // 实体类中有该属性时调用
        if (metaObject.hasSetter("createTime")) {
            this.fillStrategy(metaObject, "createTime", LocalDateTime.now());
        }
        if (metaObject.hasSetter("createdBy")) {
            Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
            String username = authentication.getName();
            if (StringUtils.isNotBlank(username)) {
                this.fillStrategy(metaObject, "createdBy", username);
            }
        }
    }

    /**
     * 更新时填充
     *
     * @param metaObject
     */
    @Override
    public void updateFill(MetaObject metaObject) {
        // 实体类中有该属性时调用
        if (metaObject.hasSetter("updateTime")) {
            this.fillStrategy(metaObject, "updateTime", LocalDateTime.now());
        }
        if (metaObject.hasSetter("updatedBy")) {
            Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
            String username = authentication.getName();
            if (StringUtils.isNotBlank(username)) {
                this.fillStrategy(metaObject, "updatedBy", username);
            }
        }
    }
}
